﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Linq;
using System.Web;
using Wisej.Web;

namespace WisejResizeUploadSample
{
	public class ImageUpload : Upload
	{
		/// <summary>
		/// Returns or sets the size of the uploaded image.
		/// </summary>
		[DefaultValue(typeof(Size), "")]
		public Size ImageSize
		{
			get { return this._imageSize; }
			set
			{
				if (this._imageSize != value)
				{
					this._imageSize = value;
					Update();
				}
			}
		}
		private Size _imageSize;


		/// <summary>
		/// Returns or sets the size of the uploaded image.
		/// </summary>
		[DefaultValue(typeof(double), "")]
		public double ImageSizePercent
		{
			get { return this._imageSizePercent; }
			set
			{
				if (this._imageSizePercent != value)
				{
					this._imageSizePercent = value;
					Update();
				}
			}
		}
		private double _imageSizePercent;


		/// <summary>
		/// Returns or sets the image format. The default is "image/png".
		/// </summary>
		[DefaultValue("image/png")]
		public string MimeType
		{
			get { return this._mimeType; }
			set
			{
				if (String.IsNullOrEmpty(value))
					throw new ArgumentNullException(nameof(MimeType));

				if (this._mimeType != value)
				{
					this._mimeType = value;
					Update();
				}
			}
		}
		private string _mimeType = "image/png";


		/// <summary>
		/// Returns or sets a number between 0 and 1 indicating image quality if 
		/// the requested type is "image/jpeg" or "image/webp".
		/// </summary>
		[DefaultValue(1)]
		public float Quality
		{
			get { return this._quality; }
			set
			{
				if (value < 0 || value > 1)
					throw new ArgumentOutOfRangeException(nameof(Quality));

				if (this._quality != value)
				{
					this._quality = value;
					Update();
				}
			}
		}
		private float _quality = 1;

		protected override void OnWebRender(dynamic config)
		{
			base.OnWebRender((object)config);

			config.className = "wisej.web.ext.ImageUpload";
			config.imageSize = this.ImageSize;
			config.imageSizePercent = this.ImageSizePercent;
			config.mimeType = this.MimeType;
			config.quality = this.Quality;
		}
	}
}